package com.app.ui.fragment

import android.content.Intent
import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import com.app.R
import com.app.YYApplication
import com.app.api.InterfaceUrlConstants
import com.app.api.RequestApiData
import com.app.constants.KeyConstants
import com.app.constants.RazorConstants
import com.app.event.NearbyMenuClose
import com.app.model.UserBase
import com.app.model.response.GetVideoGirlUserResponse
import com.app.ui.activity.HomeActivity
import com.app.ui.activity.MemberSpaceActivity
import com.app.ui.activity.PhoneMatchActivity
import com.app.ui.adapter.PopularAdapter
import com.app.util.EventBusHelper
import com.app.util.Tools
import com.wbtech.ums.UmsAgent
import com.yy.ui.fragment.MyFragment
import com.yy.util.date.DateUtils
import com.yy.util.image.VolleyUtil
import com.yy.util.net.NewHttpResponeCallBack
import com.yy.util.string.StringUtils
import com.yy.widget.pullrefresh.TowHeadRefreshListView
import kotlinx.android.synthetic.main.fragment_popular.*


/**
 * Created by liujiawei on 2017/8/1.
 * 热门Tab
 */
class PopularTabFragment : MyFragment(), TowHeadRefreshListView.IXListViewListener, NewHttpResponeCallBack {

    var popularAdapter: PopularAdapter? = null
    var addCount: Int = 0

    var mContext: HomeActivity? = null

    override fun onCreateView(inflater: LayoutInflater, container: ViewGroup?, savedInstanceState: Bundle?): View? {
        mContext = activity as HomeActivity
        EventBusHelper.getDefault().register(this)
        return inflater?.inflate(R.layout.fragment_popular, container, false)
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)


//        tv_popular_title.text = "推荐"
//        if (YYApplication.getInstance().videoSpeedFlag == 1) {
//            tv_popular_title.visibility = View.GONE
//            ll_phone_voice.visibility = View.VISIBLE
//        } else {
//            tv_popular_title.visibility = View.VISIBLE
//            ll_phone_voice.visibility = View.GONE
//        }

        id_popular_error.setOnClickListener {
            initData()
        }

        id_popular_list.setPullLoadEnable(false)
        id_popular_list.setPullRefreshEnable(true)

        id_popular_list.setXListViewListener(this)
        id_popular_list.setRefreshTime(DateUtils.getNowDateFormat(DateUtils.DATE_FORMAT_6))
        id_popular_list.setOnItemClickListener { parent, view, position, id ->
            val obj = view.getTag(R.id.user_tag)
            if (obj != null) {
                val userBase = obj as UserBase
                UmsAgent.onCBtn(activity, RazorConstants.POPULAR_VOICE_LISTITEM_BTN)
                val intent = Intent(YYApplication.getInstance(), MemberSpaceActivity::class.java)
                intent.putExtra(KeyConstants.KEY_POSITION, position)
                intent.putExtra(KeyConstants.KEY_MEMBER, userBase)
                startActivity(intent)
            }

        }
        popularAdapter = fragmentManager?.let { PopularAdapter(activity as HomeActivity, it) }
        id_popular_list.adapter = popularAdapter

        ll_phone_voice_click.setOnClickListener {
            UmsAgent.onCBtn(activity, RazorConstants.POPULAR_VOICE_SPEED_BTN)
            val i = Intent(activity, PhoneMatchActivity::class.java)
            startActivity(i)
        }

        val imageUrl = YYApplication.getInstance().currentUser?.image?.imageUrl
        if (!StringUtils.isEmpty(imageUrl)) {
            YYApplication.getInstance().imageLoader.get(imageUrl,
                    VolleyUtil.getImageListener(iv_popular_head_left, null, null),
                    iv_popular_head_left!!.measuredWidth, iv_popular_head_left!!.measuredHeight, true)
        }

        initData()
    }

    private fun initData() {
        if (addCount > 2) {
            Tools.showToast("没有更多数据了ಥ_ಥ")
            id_popular_list.setPullLoadEnable(false)

        } else {
            RequestApiData.getInstance().getVideoGirlUser(GetVideoGirlUserResponse::class.java, this)
        }
    }


    override fun onRefresh() {
        addCount = 0
        popularAdapter?.clearData()
        id_popular_list.setPullLoadEnable(false)

        initData()
    }

    override fun onLoadMore() {
        initData()
    }

    override fun onResponeStart(apiName: String?) {
        if (activity != null) {
            (activity as HomeActivity).showLoadingDialog("正在加载...")
        }
    }

    override fun onLoading(apiName: String?, count: Long, current: Long) {
    }

    override fun onSuccess(apiName: String?, `object`: Any?) {
        if (activity != null) {
            (activity as HomeActivity).dismissLoadingDialog()
        }

        if (id_popular_list != null) {
            id_popular_list.stopLoadMore()
            id_popular_list.stopRefresh()
            if (InterfaceUrlConstants.URL_GETVIDEOGIRLUSER == apiName && `object` is GetVideoGirlUserResponse) {
                val listUser = `object`.listUser
                if (listUser != null) {
                    addCount += 1
                    id_popular_list.setPullLoadEnable(true)
                    if (id_popular_error != null) {
                        id_popular_error.visibility = View.GONE
                    }
                    popularAdapter?.setData(listUser)
                    popularAdapter?.notifyDataSetChanged()
                } else {
                    id_popular_list.setPullLoadEnable(false)
                    if (id_popular_error != null) {
                        id_popular_error.visibility = View.VISIBLE
                    }
                }
            }
        }
    }

    override fun onFailure(apiName: String?, t: Throwable?, errorNo: Int, strMsg: String?) {
        if (activity != null) {
            (activity as HomeActivity).dismissLoadingDialog()
        }
        id_popular_list.stopRefresh()
        id_popular_list.stopLoadMore()
        id_popular_error.visibility = View.VISIBLE
    }

    override fun onVisible(isInit: Boolean) {
//        mContext?.setHeadMenuLinear(dynamic_menu_view)
    }

    /**
     * 关闭页眉
     * @param info
     */
    fun onEventMainThread(info: NearbyMenuClose?) {
        if (info != null) {
            if (info.isClose) {
                //是关闭页眉
                mContext?.closeHeadMenuHome()
            }
        }
    }

    override fun onDestroyView() {
        super.onDestroyView()
        EventBusHelper.getDefault().unregister(this)
    }


}
