package com.app.widget.dialog

import android.annotation.SuppressLint
import android.os.Bundle
import android.os.Handler
import android.support.v4.app.DialogFragment
import android.support.v4.app.FragmentManager
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.EditText
import android.widget.ImageView
import android.widget.RelativeLayout
import android.widget.TextView
import com.app.R
import com.app.YYApplication
import com.app.api.InterfaceUrlConstants
import com.app.api.RequestApiData
import com.app.constants.Constants
import com.app.constants.RazorConstants
import com.app.model.response.RandomCotentResponse
import com.app.util.Tools
import com.wbtech.ums.UmsAgent
import com.yy.util.image.VolleyUtil
import com.yy.util.net.NewHttpResponeCallBack
import pl.droidsonroids.gif.GifDrawable
import pl.droidsonroids.gif.GifImageView

/**
 * @Description:  漂流瓶dialog(扔一个,见一个,加载中,没见到)
 * @Author:         Mazh
 */
class PiaoLiuDiaLog : DialogFragment() {
    override fun onCreate(savedInstanceState: Bundle?) {
        setStyle(STYLE_NO_FRAME, R.style.AgePickerTheme)
        super.onCreate(savedInstanceState)
    }


    override fun onCreateView(inflater: LayoutInflater, container: ViewGroup?, savedInstanceState: Bundle?): View? {
//        Density.setDensity(activity.application)
//        Density.setDefault(activity)
        return getFragmentView()
    }

    override fun show(manager: FragmentManager, tag: String) {
        try {
            super.show(manager, tag)
        } catch (e: IllegalStateException) {
            e.printStackTrace()
            // 解决java.lang.IllegalStateException: Can not perform this action问题
            val ft = manager.beginTransaction()
            ft.add(this, tag)
            try {
                ft.commitAllowingStateLoss()
            } catch (e1: Exception) {
                e1.printStackTrace()
            }
        }
    }

    private fun getFragmentView(): View? {
        if (activity == null) {
            return null
        }

        var view: View? = null
        var type = arguments?.getInt(Constants.FLAG_COMMOM_DIALOG_TYPE)
        when (type) {
            PICK -> {//捡一个
                view = getPickView()
            }
            THROW -> {//扔一个
                view = getThrowView()
            }
            NOTFOUND -> {//没捡到
                view = getNotFoundView()
            }
            LOADING -> {//加载loading
                view = getLoadingView()
            }
        }
        return view
    }


    /**
     * 扔一个
     */
    private lateinit var editText: EditText

    private fun getThrowView(): View {
        var view = View.inflate(activity, R.layout.dialog_pl_throw, null)
        editText = view.findViewById(R.id.etContent)

        var tvLeft:TextView = view.findViewById(R.id.tvLeft)
        tvLeft.setOnClickListener {
            if (piaoLiuListener != null) {
                piaoLiuListener?.disMiss()
                dismiss()
            }
        }
        var tvRandom:TextView = view.findViewById(R.id.tvRandom)
        tvRandom.setOnClickListener {
            UmsAgent.onCBtn(activity, RazorConstants.SHAKE_RANDOM)
            getThrowData()
        }
        var tvRight:TextView = view.findViewById(R.id.tvRight);
        tvRight.setOnClickListener {
            if (editText.text.trim().length < 4) {
                Tools.showToast("不得少于 4 个字数哦! ")
                return@setOnClickListener
            }

            if (piaoLiuListener != null) {
                piaoLiuListener?.throwContent(editText.text.toString().trim())
                editText.setText("")
            }
        }

        return view
    }

    /**
     * 捡一个
     */
    @SuppressLint("SetTextI18n")
    private fun getPickView(): View {
        var view = View.inflate(activity, R.layout.dialog_pl_pick, null)
        var tvLeft:TextView = view.findViewById(R.id.tvLeft)
        tvLeft.setOnClickListener {
            if (piaoLiuListener != null) {
                piaoLiuListener?.disMiss()
                dismiss()
            }
        }
        var tvRight:TextView = view.findViewById(R.id.tvRight)
        tvRight.setOnClickListener {

            if (piaoLiuListener != null) {
                dismiss()
                piaoLiuListener?.pick()
            }
        }

        var tvTitle: TextView = view.findViewById(R.id.tvTitleContent)
        tvTitle.text = "收到来自 \"$nickName\" 桃花信"

        var ivIcon: ImageView = view.findViewById(R.id.ivIcon)
        ivIcon.setOnClickListener {
            if (piaoLiuListener != null) {
                dismiss()
                piaoLiuListener?.iconClick()
            }
        }
        YYApplication.getInstance().ugcImageLoader.get(thumbnailUrl,
                VolleyUtil.getImageListener(ivIcon, R.drawable.radio_women_default_bg
                        , R.drawable.radio_women_default_bg),
                ivIcon.width, ivIcon.height, 8f)


        return view
    }

    /**
     * 没捡到
     */
    private fun getNotFoundView(): View {
        var view = View.inflate(activity, R.layout.dialog_pl_notfound, null)
        var tvLeft:TextView = view.findViewById(R.id.tvLeft)
        tvLeft.setOnClickListener {
            if (piaoLiuListener != null) {
                piaoLiuListener?.disMiss()
                dismiss()
            }
        }
        var tvRight:TextView = view.findViewById(R.id.tvRight)
        tvRight.setOnClickListener {
            if (piaoLiuListener != null) {
                dismiss()
                piaoLiuListener?.noFound()
            }
        }
        return view
    }

    /**
     * loading
     */
    private var gifView: GifImageView? = null

    private fun getLoadingView(): View {
        var view = View.inflate(activity, R.layout.dialog_pl_loading, null)
        gifView = view.findViewById(R.id.gifPick)
        startGif(mType)
        return view
    }

    private var mType = -1
    fun setGifType(type: Int) {
        mType = type
    }

    /**
     * 开启动画
     */
    private fun startGif(type: Int) {
        if (type == PICK) {
            gifView?.setImageResource(R.drawable.pick_gif)
        } else {
            gifView?.setImageResource(R.drawable.throw_gif)
        }

        if (gifView?.drawable != null)
            with(gifView?.drawable as GifDrawable) {
                loopCount = 65535
                reset()
                start()
            }
    }

    private var handler = Handler()
    var runnable: Runnable = Runnable {
        dismissAllowingStateLoss()
        if (gifView?.drawable != null)
            with(gifView?.drawable as GifDrawable) {
                stop()
                recycle()
            }
    }

    /**
     * 停止动画
     */
    fun stopGif() {
        if (isAdded || isVisible) {
            handler.postDelayed(runnable, 0)
        }
    }

    override fun onDestroyView() {
        super.onDestroyView()
        if (null != piaoLiuListener) piaoLiuListener?.disMiss()
        if (gifView?.drawable != null)
            (gifView?.drawable as GifDrawable).recycle()
        if (handler != null && runnable != null) {
            handler.removeCallbacks(runnable)
        }
    }

    companion object {
        @JvmStatic
        fun newInstance(type: Int): PiaoLiuDiaLog {
            val fag = PiaoLiuDiaLog()
            val args = Bundle()
            args.putInt(Constants.FLAG_COMMOM_DIALOG_TYPE, type)
            fag.arguments = args
            return fag
        }

        @JvmField
        val PICK = 1
        @JvmField
        val THROW = 2
        @JvmField
        val NOTFOUND = 3
        @JvmField
        val LOADING = 4

    }

    private var piaoLiuListener: PiaoLiuListener? = null

    fun setPiaoLiuListener(piaoLiuListener: PiaoLiuListener) {
        this.piaoLiuListener = piaoLiuListener
    }

    interface PiaoLiuListener {
        fun throwContent(content: String)
        fun pick()
        fun noFound()
        fun disMiss()
        fun iconClick()
    }

    /**
     * 获取随机内容
     */
    private fun getThrowData() {
        RequestApiData.getInstance().getRandomCotent(RandomCotentResponse::class.java, object : NewHttpResponeCallBack {
            override fun onResponeStart(apiName: String?) {
            }

            override fun onLoading(apiName: String?, count: Long, current: Long) {
            }

            override fun onFailure(apiName: String?, t: Throwable?, errorNo: Int, strMsg: String?) {
                Tools.showToast("网络出现问题,请稍后再试!")
            }

            override fun onSuccess(apiName: String?, res: Any?) {
                if (apiName.equals(InterfaceUrlConstants.URL_RANDOM_CONTENT)) {
                    var resp = res as RandomCotentResponse
                    editText.setText(resp.content)
                }
            }
        })
    }

    /**
     * 设置捡到内容dialog 的 头像
     */
    lateinit var thumbnailUrl: String

    fun setImgIcon(thumbnailUrl: String) {
        this.thumbnailUrl = thumbnailUrl
    }

    /**
     * 设置捡到内容dialog 的 昵称
     */
    lateinit var nickName: String

    fun setPickTitle(nickName: String) {
        this.nickName = nickName
    }
}