package com.app.widget.yyytitlebar

import android.app.Activity
import android.content.Context
import android.graphics.Typeface
import android.text.Spannable
import android.text.SpannableString
import android.text.style.RelativeSizeSpan
import android.text.style.StyleSpan
import android.view.LayoutInflater
import android.view.View
import android.widget.LinearLayout
import android.widget.PopupWindow
import android.widget.TextView
import com.app.R
import com.app.constants.RazorConstants
import com.app.db.YouYuanDb
import com.app.event.HomeTabSwitchEvent
import com.nineoldandroids.animation.AnimatorSet
import com.nineoldandroids.animation.ObjectAnimator
import com.nineoldandroids.animation.ValueAnimator
import com.wbtech.ums.UmsAgent
import de.greenrobot.event.EventBus


class PopWindowHolder {

    companion object {
        private lateinit var mActivity: Activity
        private var instance: PopWindowHolder? = null
        @Synchronized
        fun get(context: Context): PopWindowHolder {
            mActivity = context as Activity
            if (instance == null) {
                instance = PopWindowHolder(context)
            }
            return instance as PopWindowHolder
        }
    }

    private var popupWindow: PopupWindow
    private var tvMessageTips: TextView
    private val animatorSet = AnimatorSet()
    private var needShow = true
    val times: Long = 800

    private constructor(context: Context) {
        var contentView = LayoutInflater.from(context).inflate(
                R.layout.title_pop_window, null)
        popupWindow = PopupWindow(contentView,
                LinearLayout.LayoutParams.WRAP_CONTENT, LinearLayout.LayoutParams.WRAP_CONTENT, true)
        with(popupWindow) {
            setTouchInterceptor { _, _ -> false }
            isOutsideTouchable = false
            isFocusable = false
            isTouchable = true
        }

        tvMessageTips = contentView.findViewById(R.id.tvMessageTips)
        contentView.setOnClickListener {
            UmsAgent.onCBtn(context, RazorConstants.SHAKE_BREATHING_STRIP)
            jumpMessage(context)
        }

        var oa1 = with(ObjectAnimator.ofFloat(tvMessageTips, "scaleX", 1f, 0.95f, 1f)) {
            repeatCount = ValueAnimator.INFINITE
            duration = times
            this
        }
        var oa2 = with(ObjectAnimator.ofFloat(tvMessageTips, "scaleY", 1f, 0.95f, 1f)) {
            repeatCount = ValueAnimator.INFINITE
            duration = times
            this
        }

        with(animatorSet) {
            playTogether(oa1, oa2)
        }
    }

    fun setMessageNum() {
        //内容
        if (mActivity.isFinishing) {
            return
        }
        // 获取数据库中的页眉
        val db = YouYuanDb.getInstance(mActivity)
        db.getHeadMenuList {
            // 获取数据库中的私信数
            db.getAllUnreadMsgBoxCount { num ->
                if (tvMessageTips != null && num > 0 && it != null && needShow) {
                    showPop(showView)
                    //时间
                    var str = "有 ${num} 条消息等待查收"
                    var span = SpannableString(str)
                    span.setSpan(RelativeSizeSpan(1.5f), 2, str.length - 8, Spannable.SPAN_EXCLUSIVE_EXCLUSIVE)
                    span.setSpan(StyleSpan(Typeface.BOLD), 2, str.length - 8, Spannable.SPAN_EXCLUSIVE_EXCLUSIVE)
                    span.setSpan(StyleSpan(Typeface.ITALIC), 2, str.length - 8, Spannable.SPAN_EXCLUSIVE_EXCLUSIVE)
                    tvMessageTips.text = span
                } else {
                    disMissPop()
                }
            }
        }
    }


    /**
     * 男用户 跳转 PersonalLetterActivity
     * 女用户 跳转到 PersonalLetterTabFragment
     */
    fun jumpMessage(context: Context) {
//        PersonalLetterActivity.openActivity(context)
        EventBus.getDefault().post(HomeTabSwitchEvent(3))
    }

    fun setNeedShow(needShow: Boolean) {
        this.needShow = needShow
    }

    /**
     * 显示pop
     */
    private fun showPop(view: View) {
        animatorSet.start()
        view.post {
            val location = IntArray(2)
            view.getLocationOnScreen(location)
            val x = location[0]//获取当前位置的横坐标
            val y = location[1]//获取当前位置的纵坐标
//            when {
//                x == 0 || y == 0 -> {
            popupWindow.showAsDropDown(view, 0, 10)
//                }
//                else -> {
//                    popupWindow.showAtLocation(view, Gravity.NO_GRAVITY, x, y + view.height + view.height / 5+Tools.getStatusBarH(mActivity))
//                }
//            }
        }
    }

    /**
     * 隐藏pop
     */
    private fun disMissPop() {
        popupWindow.dismiss()
    }

    /**
     * 在哪个view的位置显示
     */
    private lateinit var showView: View

    fun setShowView(ivMessage: View) {
        showView = ivMessage
    }

    fun onDestroy() {
        instance = null
    }

}
